@@ -13,19 +13,23 @@
 #    under the License.
 
 import copy
+import eventlet
 import fixtures
 import functools
 import logging as pylogging
 import mock
 import platform
+import sys
 import time
 
 from oslo_log import formatters
 from oslo_log import log as logging
 from oslotest import base
+import six
 import testtools
 
 from oslo_privsep import capabilities
+from oslo_privsep import comm
 from oslo_privsep import daemon
 from oslo_privsep.tests import testctx
 
@@ -149,6 +153,7 @@ class DaemonTest(base.BaseTestCase):
         context = mock.NonCallableMock()
         context.conf.user = 42
         context.conf.group = 84
+        context.conf.thread_pool_size = 10
         context.conf.capabilities = [
             capabilities.CAP_SYS_ADMIN, capabilities.CAP_NET_ADMIN]
 
@@ -177,3 +182,63 @@ class WithContextTest(testctx.TestContextTestCase):
         self.assertRaisesRegex(
             NameError, 'undecorated not exported',
             testctx.context._wrap, undecorated)
+
+
+class ClientChannelTestCase(base.BaseTestCase):
+
+    DICT = {
+        'string_1': ('tuple_1', six.b('tuple_2')),
+        six.b('byte_1'): ['list_1', 'list_2'],
+    }
+
+    EXPECTED = {
+        'string_1': ('tuple_1', six.b('tuple_2')),
+        'byte_1': ['list_1', 'list_2'],
+    }
+
+    def setUp(self):
+        super(ClientChannelTestCase, self).setUp()
+        with mock.patch.object(comm.ClientChannel, '__init__'), \
+                mock.patch.object(daemon._ClientChannel, 'exchange_ping'):
+            self.client_channel = daemon._ClientChannel(mock.ANY)
+
+    def test_out_of_band_log_message(self):
+        message = [daemon.Message.LOG, self.DICT]
+        with mock.patch.object(pylogging, 'makeLogRecord') as mock_make_log, \
+                mock.patch.object(daemon.LOG, 'isEnabledFor',
+                                  return_value=False):
+            self.client_channel.out_of_band(message)
+            mock_make_log.assert_called_once_with(self.EXPECTED)
+
+    def test_out_of_band_not_log_message(self):
+        with mock.patch.object(daemon.LOG, 'warning') as mock_warning:
+            self.client_channel.out_of_band([daemon.Message.PING])
+            mock_warning.assert_called_once()
+
+
+class UnMonkeyPatch(base.BaseTestCase):
+
+    @testtools.skipIf(sys.version_info < (3, 0), 'works only with python 3')
+    def test_un_monkey_patch(self):
+        self.assertFalse(any(
+            eventlet.patcher.is_monkey_patched(eventlet_mod_name)
+            for eventlet_mod_name in daemon.EVENTLET_MODULES))
+
+        eventlet.monkey_patch()
+        self.assertTrue(any(
+            eventlet.patcher.is_monkey_patched(eventlet_mod_name)
+            for eventlet_mod_name in daemon.EVENTLET_MODULES))
+
+        daemon.un_monkey_patch()
+        for eventlet_mod_name, func_modules in daemon.EVENTLET_LIBRARIES:
+            if not eventlet.patcher.is_monkey_patched(eventlet_mod_name):
+                continue
+
+            for name, green_mod in func_modules():
+                orig_mod = eventlet.patcher.original(name)
+                patched_mod = sys.modules.get(name)
+                for attr_name in green_mod.__patched__:
+                    un_monkey_patched_attr = getattr(patched_mod, attr_name,
+                                                     None)
+                    original_attr = getattr(orig_mod, attr_name, None)
+                    self.assertEqual(un_monkey_patched_attr, original_attr)
